@@ -1,6 +1,9 @@
 #!/bin/bash
+# shellcheck shell=bash
 
+# shellcheck source=base.sh
 . "$TESTLIBPATH/base.sh" || exit 137
+# shellcheck source=random.sh
 . "$TESTLIBPATH/random.sh" || exit 137
 
 getprintername () { # Generate a name for a printer. E.g. PRINTERNAME=$(getprintername)
@@ -13,9 +16,9 @@ create_localprinter () { #Creates a printer. E.g. createlocalprinter $PRINTERNAM
 	info "create printer $TMP_PRINTERNAME"
 
 	udm-test shares/printer create \
-		--position "cn=printers,$ldap_base" \
+		--position "cn=printers,${ldap_base:?}" \
 		--set name="$TMP_PRINTERNAME" \
-		--set spoolHost="$hostname.$domainname" \
+		--set spoolHost="${hostname:?}.${domainname:?}" \
 		--set uri="parallel:/ /dev/lp0" \
 		--set model="foomatic-ppds/Apple/Apple-12_640ps-Postscript.ppd.gz" \
 		"$@"
@@ -25,7 +28,7 @@ remove_printer () { # Remove a printer. E.g. removeprinter $PRINTERNAME
 	TMP_PRINTERNAME="${1:?printername}"
 	info "remove printer $TMP_PRINTERNAME"
 	udm-test shares/printer remove \
-		--dn "cn=$TMP_PRINTERNAME,cn=printers,$ldap_base"
+		--dn "cn=$TMP_PRINTERNAME,cn=printers,${ldap_base:?}"
 }
 
 set_printer_sambaname () { # Set the Sambaname for a printer. E.g. setsambaname $PRINTERNAME $PRINTERSAMBANAME
@@ -33,7 +36,7 @@ set_printer_sambaname () { # Set the Sambaname for a printer. E.g. setsambaname
 	SAMBANAME="${2:?samba printer name}"
 	info  "setting the sambaName for printer $PRINTERNAME to the value $SAMBANAME"
 	udm-test shares/printer modify \
-		--dn "cn=$PRINTERNAME,cn=printers,$ldap_base" \
+		--dn "cn=$PRINTERNAME,cn=printers,${ldap_base:?}" \
 		--set sambaName="$SAMBANAME"
 }
 
