@@ -1,8 +1,14 @@
 #!/bin/bash
+# shellcheck shell=bash
 
+# shellcheck disable=SC2089,SC2090
+
+# shellcheck source=base.sh
 . "$TESTLIBPATH/base.sh" || exit 137
+# shellcheck source=ldap.sh
 . "$TESTLIBPATH/ldap.sh" || exit 137
 
+# shellcheck disable=SC2034
 UDM_ALL_COMPUTER_ROLES="computers/domaincontroller_backup
 computers/domaincontroller_master
 computers/domaincontroller_slave
@@ -130,7 +136,8 @@ udm_get_identifier_value () {
 	local module="$1"
 	local variableprefix="${2:-$(udm_get_module_variable_prefix "$module")}"
 
-	local idattr=$(udm_get_identifier_attribute "$module")
+	local idattr
+	idattr=$(udm_get_identifier_attribute "$module")
 
 	local a=
 	eval "a=\$$variableprefix${idattr//-/_}"
@@ -184,18 +191,12 @@ udm_exists () {
 	local ldaplocation="${4:-$superordinate}"
 	local objectname="${5:-$(udm_get_identifier_value "$module" "$variableprefix")}"
 
-	local cmd="udm-test '$module' list"
-	if [ -n "$superordinate" ]; then
-		cmd+=" --superordinate '$superordinate'"
-	fi
+	local dn
+	dn="$(udm_get_ldap_identifier_qualifier "$module")=$objectname,${ldaplocation:-$(udm_get_ldap_prefix "$module")$ldap_base}"
+	# shellcheck disable=SC2016
+	local cmd="udm-test '$module' list ${superordinate:+--superordinate '$superordinate'} | grep -Fx 'DN: $dn'"
 
-	if [ -n "$ldaplocation" ]; then
-		cmd+=" | egrep '^DN: $(udm_get_ldap_identifier_qualifier "$module")=$objectname,$ldaplocation$'"
-	else
-		cmd+=" | egrep '^DN: $(udm_get_ldap_identifier_qualifier "$module")=$objectname,$(udm_get_ldap_prefix "$module")$ldap_base$'"
-	fi
-
-	if log_and_eval_execute $cmd; then
+	if log_and_eval_execute "$cmd"; then
 		info "$module object $objectname exists"
 		return 0
 	else
@@ -216,15 +217,9 @@ udm_create () {
 	local objectname="${1:-$(udm_get_identifier_value "$module" "$variableprefix")}"
 	shift
 
-	local cmd="udm-test '$module' create"
-	if [ -n "$superordinate" ]; then
-		cmd+=" --superordinate '$superordinate'"
-	fi
-	if [ -n "$ldaplocation" ]; then
-		cmd+=" --position '$ldaplocation'"
-	else
-		cmd+=" --position \"$(udm_get_ldap_prefix "$module")$ldap_base\""
-	fi
+	# shellcheck disable=SC2016
+	local cmd="udm-test '$module' create ${superordinate:+--superordinate '$superordinate'}"
+	cmd+=" --position '${ldaplocation:-$(udm_get_ldap_prefix "$module")$ldap_base}'"
 
 	local params=
 	local var=
@@ -235,7 +230,8 @@ udm_create () {
 		fi
 	done
 
-	if log_and_eval_execute $cmd $params $@; then
+	# shellcheck disable=SC2086,SC2068
+	if log_and_eval_execute "$cmd $params $*"; then
 		info "created $module object $objectname"
 		return 0
 	else
@@ -256,17 +252,12 @@ udm_modify () {
 	local objectname="${1:-$(udm_get_identifier_value "$module" "$variableprefix")}"
 	shift
 
-	local cmd="udm-test '$module' modify"
-	if [ -n "$superordinate" ]; then
-		cmd+=" --superordinate '$superordinate'"
-	fi
-	if [ -n "$ldaplocation" ]; then
-		cmd+=" --dn \"$(udm_get_ldap_identifier_qualifier "$module")=$objectname,$ldaplocation\""
-	else
-		cmd+=" --dn \"$(udm_get_ldap_identifier_qualifier "$module")=$objectname,$(udm_get_ldap_prefix "$module")$ldap_base\""
-	fi
+	# shellcheck disable=SC2016
+	local cmd="udm-test '$module' modify ${superordinate:+--superordinate '$superordinate'}"
+	cmd+=" --dn '$(udm_get_ldap_identifier_qualifier "$module")=$objectname,${ldaplocation:-$(udm_get_ldap_prefix "$module")$ldap_base}'"
 
-	if log_and_eval_execute $cmd $@; then
+	# shellcheck disable=SC2068,SC2086
+	if log_and_eval_execute "$cmd $*"; then
 		info "$module object $objectname modified"
 		return 0
 	else
@@ -287,17 +278,12 @@ udm_remove () {
 	local objectname="${1:-$(udm_get_identifier_value "$module" "$variableprefix")}"
 	shift
 
-	local cmd="udm-test '$module' remove"
-	if [ -n "$superordinate" ]; then
-		cmd+=" --superordinate '$superordinate'"
-	fi
-	if [ -n "$ldaplocation" ]; then
-		cmd+=" --dn \"$(udm_get_ldap_identifier_qualifier "$module")=$objectname,$ldaplocation\""
-	else
-		cmd+=" --dn \"$(udm_get_ldap_identifier_qualifier "$module")=$objectname,$(udm_get_ldap_prefix "$module")$ldap_base\""
-	fi
+	# shellcheck disable=SC2016
+	local cmd="udm-test '$module' remove ${superordinate:+--superordinate '$superordinate'}"
+	cmd+=" --dn '$(udm_get_ldap_identifier_qualifier "$module")=$objectname,${ldaplocation:-$(udm_get_ldap_prefix "$module")$ldap_base}'"
 
-	if log_and_eval_execute $cmd $@; then
+	# shellcheck disable=SC2068,SC2086
+	if log_and_eval_execute "$cmd $*"; then
 		info "removed $module object $objectname"
 		return 0
 	else
@@ -313,11 +299,7 @@ udm_ldap_remove () {
 	local ldaplocation="${4:-$superordinate}"
 	local objectname="${5:-$(udm_get_identifier_value "$module" "$variableprefix")}"
 
-	if [ -n "$ldaplocation" ]; then
-		ldap_delete "$(udm_get_ldap_identifier_qualifier "$module")=$objectname,$ldaplocation"
-	else
-		ldap_delete "$(udm_get_ldap_identifier_qualifier "$module")=$objectname,$(udm_get_ldap_prefix "$module")$ldap_base"
-	fi
+	ldap_delete "$(udm_get_ldap_identifier_qualifier "$module")=$objectname,${ldaplocation:-$(udm_get_ldap_prefix "$module")$ldap_base}"
 }
 
 udm_purge () {
@@ -339,69 +321,12 @@ udm_purge () {
 
 udm_get_required_module_attributes () {
 	local module="$1"
-
-	let local linecount="$(udm-test "$module" | wc -l)"
-	let local syntaxbeginning="$(udm-test "$module" | grep -n "$module variables:" | sed "s#:$module variables:##")"
-	let local tailcount="$linecount-$syntaxbeginning"
-
-
-	local output="$(udm-test "$module" | tail -n2 | grep -n "^$" | head -n 1)"
-	if [ -n "$output" ]; then
-		let local relativesyntaxend="${output/:/}"
-	else
-		let local relativesyntaxend="$tailcount"
-	fi
-
-	udm-test "$module" |
-		tail -n "$tailcount" |
-		head -n "$relativesyntaxend" |
-		egrep -v "^  .*:$" |
-		egrep "\(c\)|\(c,.*\)|\(.*,c\)|\(.*,c,.*\)" |
-		sed "s/^ *//" |
-		sed "s/ .*$//"
+	udm-test "$module" | sed -ne '\#'"$module"' variables:#,${/:$/d;/^\$/d;s/^\t\t\(\S\+\) (\(\S+,\)\?\<c\>\(,\S\+\)\?).*/\1/p}'
 }
 
 udm_get_plain_module_attributes () {
 	local module="$1"
-
-	let local linecount="$(udm-test "$module" | wc -l)"
-	let local syntaxbeginning="$(udm-test "$module" | grep -n "$module variables:" | sed "s#:$module variables:##")"
-	let local tailcount="$linecount - $syntaxbeginning"
-
-	local output="$(udm-test "$module" | tail -n "$tailcount" | grep -n "^$" | head -n 1)"
-	if [ -n "$output" ]; then
-	        let local relativesyntaxend="${output/:/}"
-	else
-	        let local relativesyntaxend="$tailcount"
-	fi
-
-	udm-test "$module" |
-	        tail -n "$tailcount" |
-	        head -n "$relativesyntaxend" |
-	        egrep -v "^  .*:$" |
-	        sed "s/^ *//" |
-	        sed "s/ .*$//"
-}
-
-udm_get_tab_entries () {
-	local module="$1"
-	local tabname="$2"
-
-	let local linecount="$(udm-test "$module" | wc -l)"
-	let local tabbeginning="$(udm-test "$module" | grep -n "$tabname:" | sed "s#: *$tabname:##")"
-	let local tailcount="$linecount - $tabbeginning"
-
-	local output="$(udm-test "$module" | tail -n "$tailcount" | egrep -n ".*:\$" | head -n 1 | sed "s#:.*##")"
-	if [ -n "$output" ]; then
-		let local relativetabend="$output - 1"
-	else
-		let local relativetabend="$tailcount + 1"
-	fi
-
-	udm-test "$module" |
-		tail -n "$tailcount" |
-		head -n "$relativetabend" |
-		sed "s/^ *//"
+	udm-test "$module" | sed -ne '\#'"$module"' variables:#,${/:$/d;/^\$/d;s/^\t\t\(\S\+\) .*/\1/p}'
 }
 
 udm_get_ldap_attribute () {
@@ -412,17 +337,11 @@ udm_get_ldap_attribute () {
 	local ldaplocation="${5:-$superordinate}"
 	local objectname="${6:-$(udm_get_identifier_value "$module" "$variableprefix")}"
 
-	if [ -n "$ldaplocation" ]; then
-		local branch="$(udm_get_ldap_identifier_qualifier "$module")=$objectname,$ldaplocation"
-	else
-		local branch="$(udm_get_ldap_identifier_qualifier "$module")=$objectname,$(udm_get_ldap_prefix "$module")$ldap_base"
-	fi
+	local branch
+	branch="$(udm_get_ldap_identifier_qualifier "$module")=$objectname,${ldaplocation:-$(udm_get_ldap_prefix "$module")$ldap_base}"
 
-	log_and_eval_execute "ldapsearch -xLLL -D 'cn=admin,$ldap_base' -w '`cat /etc/ldap.secret`' -b '$branch' \
-		'$attributename' |
-		grep '^$attributename' |
-		sed 's/^${attributename}\;//' |
-		sed 's/^${attributename}\: //'"
+	log_and_eval_execute "ldapsearch -xLLL -D 'cn=admin,$ldap_base' -y /etc/ldap.secret -b '$branch' '$attributename' |
+		sed -ne 's/^${attributename}\: \?//p'"
 }
 
 udm_has_object_class () {
@@ -433,9 +352,10 @@ udm_has_object_class () {
 	local ldaplocation="$5"
 	local objectname="${6:-$(udm_get_identifier_value "$module" "$variableprefix")}"
 
-	local objectclasses="$(udm_get_ldap_attribute objectClass "$module" "$variableprefix" "$superordinate" "$ldaplocation" "$objectname")"
+	local objectclasses
+	objectclasses="$(udm_get_ldap_attribute objectClass "$module" "$variableprefix" "$superordinate" "$ldaplocation" "$objectname")"
 
-	IFS="
+	local IFS="
 "
 	for class in $objectclasses; do
 		if [ "$class" == "$objectclass" ]; then
@@ -457,7 +377,8 @@ udm_verify_ldap_attribute () {
 	local ldaplocation="$6"
 	local objectname="$7"
 
-	local value="$(udm_get_ldap_attribute "$attribute" "$module" "$variableprefix"  "$superordinate" "$ldaplocation" "$objectname")"
+	local value
+	value="$(udm_get_ldap_attribute "$attribute" "$module" "$variableprefix"  "$superordinate" "$ldaplocation" "$objectname")"
 	verify_value "$attribute" "$value" "$expected_value"
 }
 
@@ -502,9 +423,9 @@ udm_get_udm_attribute () {
 	if [ -n "$superordinate" ]; then
 		cmd+=" --superordinate '$superordinate'"
 	fi
-	cmd+=" --filter \"$(udm_get_udm_filter_qualifier "$module")=$objectname\" | egrep '^ *${attribute}: ' | sed 's/^ *${attribute}: //'"
+	cmd+=" --filter '$(udm_get_udm_filter_qualifier "$module")=$objectname' | sed -nre 's/^ *${attribute}: //p'"
 
-	log_and_eval_execute $cmd
+	log_and_eval_execute "$cmd"
 }
 
 udm_verify_udm_attribute () {
@@ -516,7 +437,8 @@ udm_verify_udm_attribute () {
 	local ldaplocation="$6"
 	local objectname="$7"
 
-	local value="$(udm_get_udm_attribute "$attribute" "$module" "$variableprefix" "$superordinate" "$ldaplocation" "$objectname")"
+	local value
+	value="$(udm_get_udm_attribute "$attribute" "$module" "$variableprefix" "$superordinate" "$ldaplocation" "$objectname")"
 
 	verify_value "$attribute" "$value" "$expected_value"
 }
@@ -530,7 +452,8 @@ udm_verify_multi_value_udm_attribute_contains_ignore_case () {
 	local ldaplocation="$6"
 	local objectname="$7"
 
-	local value="$(udm_get_udm_attribute "$attribute" "$module" "$variableprefix" "$superordinate" "$ldaplocation" "$objectname")"
+	local value
+	value="$(udm_get_udm_attribute "$attribute" "$module" "$variableprefix" "$superordinate" "$ldaplocation" "$objectname")"
 
 	verify_value_contains_line_ignore_case "$attribute" "$value" "$expected_value"
 }
@@ -544,7 +467,8 @@ udm_verify_multi_value_udm_attribute_contains () {
 	local ldaplocation="$6"
 	local objectname="$7"
 
-	local value="$(udm_get_udm_attribute "$attribute" "$module" "$variableprefix" "$superordinate" "$ldaplocation" "$objectname")"
+	local value
+	value="$(udm_get_udm_attribute "$attribute" "$module" "$variableprefix" "$superordinate" "$ldaplocation" "$objectname")"
 
 	verify_value_contains_line "$attribute" "$value" "$expected_value"
 }
@@ -708,7 +632,6 @@ udm_check_flag_attribute () {
 
 	udm_check_required_singlevalue_attribute "$attribute" "0" "1" \
 		"$module" "$variableprefix" "$superordinate" "$ldaplocation" "$objectname"
-	return $?
 }
 
 udm_check_syntax_for_attribute () {
@@ -775,7 +698,8 @@ udm_check_syntax_for_attribute () {
 }
 
 udm_kill_univention_cli_server () {
-	local pids="$(pgrep -f "univention-cli-server")"
+	local pids pid
+	pids="$(pgrep -f "univention-cli-server")"
 	for pid in $pids; do
 		info "Killing univention-cli-server with pid $pid"
 		kill "$pid"
