@@ -117,7 +117,7 @@ ID = apache
 Code = AP
 Name = Apache
 Version = 2.4
-DockerImage = httpd:2.4.23-alpine
+DockerImage = docker-test.software-univention.de/httpd:2.4.23-alpine
 DockerScriptInit = httpd-foreground
 DockerScriptStoreData =
 DockerScriptRestoreDataBeforeSetup =
