@@ -30,17 +30,20 @@
 # <https://www.gnu.org/licenses/>.
 
 from __future__ import print_function
-from univention.testing.strings import random_name, random_version
-from univention.testing.debian_package import DebianPackage
-from univention.testing.ucr import UCSTestConfigRegistry
-from univention.config_registry import handler_set, ConfigRegistry
-from univention.testing import umc
+
+import json
 import os
 import shutil
 import subprocess
 import threading
+
 import requests
-import json
+
+from univention.config_registry import ConfigRegistry, handler_set
+from univention.testing import umc
+from univention.testing.debian_package import DebianPackage
+from univention.testing.strings import random_name, random_version
+from univention.testing.ucr import UCSTestConfigRegistry
 
 
 class UCSTest_Docker_Exception(Exception):
@@ -317,11 +320,14 @@ class App(object):
 		if ret != 0:
 			raise UCSTest_DockerApp_InstallationFailed()
 
-		self.ucr.load()
-		self.container_id = self.ucr.get('appcenter/apps/%s/container' % self.app_name)
+		self.reload_container_id()
 
 		self.installed = True
 
+	def reload_container_id(self):
+		self.ucr.load()
+		self.container_id = self.ucr.get('appcenter/apps/%s/container' % self.app_name)
+
 	def file(self, fname):
 		if fname.startswith('/'):
 			fname = fname[1:]
@@ -379,8 +385,7 @@ class App(object):
 			finished = progress.get('finished', False)
 		if not progress['result'].get('success', False) or not progress['result'].get('can_continue', False):
 			raise UCTTest_DockerApp_UMCInstallFailed(progress, errors)
-		self.ucr.load()
-		self.container_id = self.ucr.get('appcenter/apps/%s/container' % self.app_name)
+		self.reload_container_id()
 		self.installed = True
 		if errors:
 			raise UCTTest_DockerApp_UMCInstallFailed(None, errors)
@@ -412,8 +417,7 @@ class App(object):
 		ret = subprocess.call(' '.join(cmd), shell=True)
 		if ret != 0:
 			raise UCSTest_DockerApp_UpgradeFailed()
-		self.ucr.load()
-		self.container_id = self.ucr.get('appcenter/apps/%s/container' % self.app_name)
+		self.reload_container_id()
 		self.installed = True
 
 	def verify(self, joined=True):
@@ -512,6 +516,8 @@ echo "TEST-%(app_name)s" >>/var/www/%(app_name)s/index.txt
 
 	def configure_tinyapp_modproxy(self):
 		fqdn = '%(hostname)s.%(domainname)s' % self.ucr
+		self.execute_command_in_container('apk update')
+		self.execute_command_in_container('apk upgrade')
 		self.execute_command_in_container('apk add apache2-ssl')
 		self.execute_command_in_container("sed -i 's#/var/www/localhost/htdocs#/web/html#g' /etc/apache2/conf.d/ssl.conf")
 		self.execute_command_in_container("sed -i 's#/var/www/localhost/cgi-bin#/web/cgi-bin#g' /etc/apache2/conf.d/ssl.conf")
@@ -650,10 +656,16 @@ Virtualization=Virtualisierung''')
 			if not os.path.isdir(directory):
 				continue
 			print('create_appcenter_json.py for %s' % vv)
-			subprocess.check_call('./create_appcenter_json.py -u %(version)s -d /var/www -o /var/www/meta-inf/%(version)s/index.json.gz -s http://%(fqdn)s -t /var/www/meta-inf/%(version)s/all.tar' %
-				{'version': vv, 'fqdn': '%s.%s' % (self.ucr['hostname'], self.ucr['domainname'])}, shell=True)
-			subprocess.check_call('zsyncmake -u http://%(fqdn)s/meta-inf/%(version)s/all.tar.gz -z -o /var/www/meta-inf/%(version)s/all.tar.zsync /var/www/meta-inf/%(version)s/all.tar' %
-				{'version': vv, 'fqdn': '%s.%s' % (self.ucr['hostname'], self.ucr['domainname'])}, shell=True)
+			subprocess.check_call(
+				'./create_appcenter_json.py -u %(version)s -d /var/www -o /var/www/meta-inf/%(version)s/index.json.gz -s http://%(fqdn)s -t /var/www/meta-inf/%(version)s/all.tar' % {
+					'version': vv,
+					'fqdn': '%s.%s' % (self.ucr['hostname'], self.ucr['domainname'])
+				}, shell=True)
+			subprocess.check_call(
+				'zsyncmake -u http://%(fqdn)s/meta-inf/%(version)s/all.tar.gz -z -o /var/www/meta-inf/%(version)s/all.tar.zsync /var/www/meta-inf/%(version)s/all.tar' % {
+					'version': vv,
+					'fqdn': '%s.%s' % (self.ucr['hostname'], self.ucr['domainname'])
+				}, shell=True)
 		subprocess.check_call('univention-app update', shell=True)
 
 	def cleanup(self):
@@ -904,4 +916,4 @@ def get_dummy_svg():
          style="fill:#ffffff;fill-opacity:1;fill-rule:nonzero;stroke:none" />
     </g>
   </g>
-</svg>'''
+</svg>'''  # noqa: E101
