@@ -46,9 +46,12 @@ The API is currently under heavy development and may/will change before next UCS
 
 from __future__ import print_function
 
+import base64
 import copy
+import functools
 import os
 import pipes
+import random
 import subprocess
 import sys
 import time
@@ -56,9 +59,9 @@ from typing import Any, Dict, Iterable, List, Mapping, Optional, Sequence, Text,
 
 import ldap
 import ldap.filter
+import psutil
 import six
 
-import psutil
 import univention.admin.modules
 import univention.admin.objects
 import univention.admin.uldap
@@ -67,6 +70,11 @@ import univention.testing.ucr
 import univention.testing.utils as utils
 from univention.testing.ucs_samba import wait_for_drs_replication, DRSReplicationFailed
 
+try:
+	from inspect import getfullargspec as getargspec
+except ImportError:
+	from inspect import getargspec  # python 2
+
 
 class UCSTestUDM_Exception(Exception):
 
@@ -294,6 +302,9 @@ class UCSTestUDM(object):
 		if action == 'list' and 'policies' in args:
 			cmd.extend(['--policies=%s' % (args.pop('policies'),)])
 
+		if action == 'list' and 'filter' in args:
+			cmd.extend(['--filter=%s' % (args.pop('filter'),)])
+
 		for option in args.pop('options', ()):
 			cmd.extend(['--option', option])
 
@@ -367,6 +378,430 @@ class UCSTestUDM(object):
 		self.wait_for(modulename, dn, wait_for_replication, everything=wait_for)
 		return dn
 
+	def create_with_defaults(self, modulename, **kwargs):
+		# type: (str, **Any) -> Tuple[str, dict]
+		"""Create any object with as maximum as possible prefilled random default values"""
+		module = univention.admin.modules.get_module(modulename)
+		# TODO: cache objects
+
+		if 'position' not in kwargs and not modulename.startswith('settings/portal'):
+			kwargs['position'] = (module.object.get_default_containers(self._lo) or [self.LDAP_BASE])[0]
+
+		superordinate_props = {}
+		if 'superordinate' not in kwargs and getattr(module, 'superordinate', None) not in (None, 'settings/cn'):
+			superordinate_module = random.choice(module.superordinate) if isinstance(module.superordinate, list) else module.superordinate
+			superordinate, superordinate_props = self.create_with_defaults(superordinate_module, position=kwargs['position'])
+			kwargs['superordinate'] = kwargs['position'] = superordinate
+
+		max_recursion = kwargs.pop('max_recursion', 1)
+
+		def ldap_search(prop):
+			m, p = prop.syntax.value.split(': ', 1)
+			if max_recursion <= 0:
+				return  # random.choice(self._cleanup.get(m, [None]))
+			return self.create_with_defaults(m, max_recursion=max_recursion - 1)[1][p]
+
+		def udm_attribute(prop):
+			if max_recursion <= 0:
+				return  # random.choice(self._cleanup.get(prop.syntax.udm_module, [None]))
+
+			# TODO: parse udm_filter and set values
+			if prop.syntax.udm_filter:
+				return
+
+			return self.create_with_defaults(prop.syntax.udm_module, max_recursion=max_recursion - 1)[1][prop.syntax.attribute]
+
+		def udm_objects(prop):
+			m = list(reversed(prop.syntax.udm_modules))
+			try:
+				m.remove('computers/computer')
+				m.append('computers/linux')
+				m.append('computers/windows')
+				m.append('computers/ubuntu')
+			except ValueError:
+				pass
+			for mod in ('computers/domaincontroller_master', 'container/dc'):
+				try:
+					m.remove(mod)
+				except ValueError:
+					pass
+
+			if max_recursion <= 0:
+				if prop.syntax.key == 'dn':
+					return  # random.choice(self._cleanup.get(m[0], [None]))  # warning: would cause circular group memberships for groups/group
+				return
+
+			# TODO: parse udm_filter and set values
+			if prop.syntax.udm_filter:
+				return
+
+			_dn, _props = self.create_with_defaults(m[0], max_recursion=max_recursion - 1)
+			try:
+				p = prop.syntax.key % _props
+			except KeyError:
+				obj = univention.admin.objects.get(univention.admin.modules.get(m[0]), None, self._lo, None, _dn)
+				# obj.open()
+				p = prop.syntax.key % obj.info
+			if p == 'dn':
+				return _dn
+			return p
+
+		def choices(syntax_name):
+			def func(prop):
+				return random.choice(getattr(univention.admin.syntax, syntax_name, prop.syntax).choices)[0]
+			return func
+
+		def complex(syntax_name):
+			def func(prop):
+				syn = getattr(univention.admin.syntax, syntax_name)
+				if not all(s[1].name in syntax_classes_mapping for s in syn.subsyntaxes):
+					# TODO: warning
+					return
+
+				def _quote(s):
+					return s if '"' not in s else '"%s"' % (s.replace('\\', '\\\\').replace('"', '\\"'),)
+				functions = [
+					_func(syntax_classes_mapping[s[1].name], prop)
+					for s in syn.subsyntaxes
+				]
+				return ' '.join(_quote(f()) for f in functions)
+			return func
+
+		def known_mail_address():
+			if len(known_mail_address.cache) >= 5:
+				return '%s@%s' % (uts.random_name(), random.choice(known_mail_address.cache))
+			email = uts.random_email()
+			domain = email.rsplit('@', 1)[-1]
+			self.create_with_defaults('mail/domain', name=domain)
+			known_mail_address.cache.append(domain)
+			return email
+		known_mail_address.cache = []
+
+		def default_container(prop):
+			# Bug #53827
+			class DefaultContainer(univention.admin.syntax.UDM_Objects):
+				"""
+				Syntax to select a |UCS| default container from |LDAP|
+				"""
+				udm_modules = ('container/cn', 'container/ou', 'container/dc')
+				regex = None
+				key = '%(name)s'
+				label = '%(name)s'
+				simple = True
+			s = prop.syntax
+			prop.syntax = DefaultContainer()
+			try:
+				return udm_objects(prop)
+			finally:
+				prop.syntax = s
+
+		def random_ip():
+			return uts.random_ip(iter(range(11, 121)))
+
+		syntax_classes_mapping = {
+			'string': uts.random_string,
+			'string_numbers_letters_dots': uts.random_string,
+			'string_numbers_letters_dots_spaces': uts.random_string,
+			'string64': lambda: uts.random_string(64),
+			'string6': lambda: uts.random_string(6),
+			'HalfString': uts.random_string,
+			'OneThirdString': uts.random_string,
+			'TwoThirdsString': uts.random_string,
+			'FiveThirdsString': uts.random_string,
+			'TwoString': uts.random_string,
+			'IA5string': uts.random_string,
+			'integer': lambda: uts.random_int(0, 100000),
+			'integerOrEmpty': lambda: uts.random_int(1, 100000),
+			'uid': uts.random_username,
+			'gid': uts.random_groupname,
+			'userPasswd': uts.random_string,
+			'passwd': uts.random_string,
+			'Country': choices('Country'),
+			'univentionAdminModules': choices('univentionAdminModules'),
+			'SambaPrivileges': choices('SambaPrivileges'),
+			'sambaGroupType': choices('sambaGroupType'),
+			'adGroupType': choices('adGroupType'),
+			'ipProtocol': choices('ipProtocol'),
+			'Hour': choices('Hour'),
+			'Minute': choices('Minute'),
+			'Month': choices('Month'),
+			'Weekday': choices('Weekday'),
+			'Day': choices('Day'),
+			'NewPortalEntryLinkTarget': choices('NewPortalEntryLinkTarget'),
+			'NewPortalDefaultLinkTarget': choices('NewPortalDefaultLinkTarget'),
+			'AllowDeny': choices('AllowDeny'),
+			'timeSpec': choices('timeSpec'),
+			'booleanNone': choices('booleanNone'),
+			'netbiosNodeType': choices('netbiosNodeType'),
+			'ddnsUpdates': choices('ddnsUpdates'),
+			'ddnsUpdateStyle': choices('ddnsUpdateStyle'),
+			'language': choices('language'),
+			'AllowDenyIgnore': choices('AllowDenyIgnore'),
+			'emailForwardSetting': choices('emailForwardSetting'),
+			'UCSServerRole': choices('UCSServerRole'),
+			'PortalFontColor': choices('PortalFontColor'),
+			'PortalDefaultLinkTarget': choices('PortalDefaultLinkTarget'),
+			'PortalCategory': choices('PortalCategory'),
+			'AuthRestriction': choices('AuthRestriction'),
+			'PortalEntryLinkTarget': choices('PortalEntryLinkTarget'),
+			'optionsUsersUser': choices('optionsUsersUser'),
+			'nfssync': choices('nfssync'),
+			'auto_one_zero': choices('auto_one_zero'),
+			'TimeZone': choices('TimeZone'),
+			'MAC_Address': uts.random_mac,
+			'ipAddress': random_ip,
+			'IPv4_AddressRange': lambda: '%s.2 %s.254' % tuple([random_ip().rsplit('.', 1)[0]] * 2),
+			'ipv4Address': random_ip,
+			'absolutePath': lambda: '/' + uts.random_string(),
+			'sharePath': lambda: '/' + uts.random_string(),
+			'BaseFilename': lambda: '%s.%s' % (uts.random_string(), uts.random_string(3)),
+			'PrinterURI': lambda: '%s %s' % (random.choice(['lpd://', 'ipp://', 'http://', 'usb:/', 'socket://', 'parallel:/', 'file:/', 'smb://']), uts.random_string()),
+			'Base64Bzip2Text': lambda: base64.b64encode(__import__('bz2').compress(uts.random_string().encode())).decode('ASCII'),
+			'Base64Upload': lambda: base64.b64encode(uts.random_string().encode()).decode('ASCII'),
+			'Base64BaseUpload': lambda: base64.b64encode(uts.random_string().encode()).decode('ASCII'),
+			'Base64Bzip2XML': lambda: base64.b64encode(__import__('bz2').compress(('<?xml?><foo>%s</foo>' % (uts.random_string(),)).encode())).decode('ASCII'),
+			'emailAddress': uts.random_email,
+			'emailAddressTemplate': lambda: '<username>@%s' % (uts.random_domain_name(),),
+			'emailAddressValidDomain': known_mail_address,
+			'primaryEmailAddressValidDomain': known_mail_address,
+			'MailHomeServer': uts.random_domain_name,
+			'boolean': lambda: uts.random_int(0, 1),
+			'disabled': lambda: uts.random_int(0, 1),
+			'locked': lambda: uts.random_int(0, 1),
+			'v4netmask': lambda: uts.random_int(1, 31),
+			'netmask': lambda: uts.random_int(1, 31),
+			'printerName': lambda: uts.random_string(16),
+			'DHCP_HardwareAddress': lambda: 'ethernet %s' % (uts.random_mac(),),
+			'hostName': uts.random_string,
+			'policyName': uts.random_string,
+			'LocalizedDescription': lambda: '%s %s' % (random.choice(['de_DE', 'en_US']), uts.random_string()),
+			'LocalizedDisplayName': lambda: '%s %s' % (random.choice(['de_DE', 'en_US']), uts.random_string()),
+			'LocalizedLink': lambda: '%s %s://%s/%s' % (random.choice(['de_DE', 'en_US']), random.choice(['http', 'https']), uts.random_domain_name(), uts.random_string()),
+			'reverseLookupSubnet': lambda: random_ip().rsplit('.', 1)[0],
+			'dnsPTR': lambda: random_ip().rsplit('.', 1)[1],
+			'dnsHostname': uts.random_domain_name,
+			'dnsName': uts.random_domain_name,
+			'dnsName_umlauts': uts.random_string,
+			'dnsSRVName': lambda: 'ldap tcp %s' % (uts.random_string(),),
+			'dnsSRVLocation': lambda: '%s %s %s %s' % (uts.random_int(), uts.random_int(), uts.random_int(), uts.random_domain_name()),
+			'mailinglist_name': uts.random_string,
+			'mail_folder_name': uts.random_string,
+			'date': uts.random_date,
+			'date2': uts.random_date,
+			'iso8601Date': uts.random_date,
+			'TimeString': lambda: uts.random_time().rsplit(':', 1)[0],  # Bug #53829
+			'phone': lambda: '+49 421 %s-%s' % (uts.random_int(10000, 99000), uts.random_int(0, 9)),
+			'postalAddress': lambda: '"%s street 1A" "%s" "%s"' % (uts.random_string(), uts.random_int(10000, 99999), uts.random_string()),
+			'keyAndValue': lambda: '%s %s' % (uts.random_string(), uts.random_string()),
+			'SambaLogonHours': lambda: uts.random_int(0, 167),
+			'DebianPackageVersion': uts.random_version,
+			'UCSVersion': uts.random_ucs_version,
+			'LDAP_Search': ldap_search,
+			'GroupDN': udm_objects,
+			'UserDN': udm_objects,
+			'HostDN': udm_objects,
+			'UCS_Server': udm_objects,
+			'Windows_Server': udm_objects,
+			'DomainController': udm_objects,
+			'ServicePrint_FQDN': udm_objects,
+			'DNS_ForwardZone': udm_objects,
+			'DNS_ReverseZone': udm_objects,
+			'NewPortalEntries': udm_objects,
+			'NewPortalCategoryEntries': udm_objects,
+			'NewPortalCategories': udm_objects,
+			'network': udm_objects,
+			'Service': udm_objects,
+			'nagiosHostsEnabledDn': udm_objects,
+			'nagiosServiceDn': udm_objects,
+			'dhcpService': udm_objects,
+			'UMC_OperationSet': udm_objects,
+			'WritableShare': udm_objects,
+			'PortalComputer': udm_objects,
+			'PortalEntries': udm_objects,
+			'Portals': udm_objects,
+			'GroupDNOrEmpty': udm_objects,
+			'PrinterProducerList': udm_objects,
+			'UserID': udm_objects,
+			'GroupID': udm_objects,
+			'printerModel': lambda: '"%s" "%s"' % (random.choice(['smb', 'cupsfilters/pxlmono.ppd', 'hp-ppd/HP/HP_LaserJet_6P.ppd', 'cups-pdf/CUPS-PDF_opt.ppd']), uts.random_string()),
+			'PrinterNames': udm_objects,
+			'PrinterDriverList': udm_attribute,
+			'Packages': udm_attribute,
+			'PackagesRemove': udm_attribute,
+			'KDE_Profile': udm_attribute,
+			'TrueFalseUp': lambda: random.choice(['TRUE', 'FALSE']),
+			'TrueFalseUpper': lambda: random.choice(['TRUE', 'FALSE', 'NONE']),
+			'TrueFalse': lambda: random.choice(['true', 'false', 'none']),
+			'TextArea': lambda: '\n'.join([uts.random_string()] * random.randint(2, 5)),
+			'SignedInteger': uts.random_int,
+			'hostOrIP': random_ip,
+			'hostname_or_ipadress_or_network': lambda: random.choice([random_ip(), uts.random_name(), '%s/%s' % (random_ip(), random.randint(1, 31))]),
+			'jpegPhoto': lambda: '/9j/2wBDAP%swAALCAABAAEBAREA/8QAFAABA%s//EABQQAQ%sD/2gAIAQEAAD8AN//Z' % ('/' * 86, 'A' * 20, 'A' * 20),
+			'Base64UMCIcon': lambda: 'AAABAAEAAQEAAAEAIAAwAAAAFgAAACgAAAABAAAAAgAAAAEAIAAAAAAABAAAAAAAAAAAAAAAAAAAAAAAAAD/////AAAAAA==',
+			'SharedFolderUserACL': complex('SharedFolderUserACL'),
+			'SharedFolderGroupACL': complex('SharedFolderGroupACL'),
+			'dnsMX': complex('dnsMX'),
+			'dnsEntry': complex('dnsEntry'),
+			'dnsEntryReverse': complex('dnsEntryReverse'),
+			'dnsEntryAlias': complex('dnsEntryAlias'),
+			'dhcpEntry': complex('dhcpEntry'),
+			'IP_AddressRange': complex('IP_AddressRange'),
+			'UCR_Variable': complex('UCR_Variable'),
+			'nfsMounts': complex('nfsMounts'),
+			'ActivationDateTimeTimezone': complex('ActivationDateTimeTimezone'),
+			'Localesubdirname_and_GNUMessageCatalog': complex('Localesubdirname_and_GNUMessageCatalog'),
+			'translationTupleShortDescription': complex('translationTupleShortDescription'),
+			'translationTupleLongDescription': complex('translationTupleLongDescription'),
+			'translationTupleTabName': complex('translationTupleTabName'),
+			'I18N_GroupName': complex('I18N_GroupName'),
+			'UMCMessageCatalogFilename_and_GNUMessageCatalog': complex('UMCMessageCatalogFilename_and_GNUMessageCatalog'),
+			'LocalizedAnonymousEmpty': complex('LocalizedAnonymousEmpty'),
+			'PortalLinks': complex('PortalLinks'),
+			'SambaMinPwdAge': complex('SambaMinPwdAge'),
+			'SambaMaxPwdAge': complex('SambaMaxPwdAge'),
+			'UMC_CommandPattern': complex('UMC_CommandPattern'),
+			'attributeMapping': complex('attributeMapping'),
+			'UNIX_TimeInterval': complex('UNIX_TimeInterval'),
+			'TimeUnits': choices('TimeUnits'),
+			'adminFixedAttributes': choices('adminFixedAttributes'),
+			'desktopFixedAttributes': choices('desktopFixedAttributes'),
+			'dhcp_dnsFixedAttributes': choices('dhcp_dnsFixedAttributes'),
+			'dhcp_dnsupdateFixedAttributes': choices('dhcp_dnsupdateFixedAttributes'),
+			'dhcp_leasetimeFixedAttributes': choices('dhcp_leasetimeFixedAttributes'),
+			'dhcp_netbiosFixedAttributes': choices('dhcp_netbiosFixedAttributes'),
+			'dhcp_routingFixedAttributes': choices('dhcp_routingFixedAttributes'),
+			'dhcp_scopeFixedAttributes': choices('dhcp_scopeFixedAttributes'),
+			'dhcp_statementsFixedAttributes': choices('dhcp_statementsFixedAttributes'),
+			'dvcp_bootFixedAttributes': choices('dvcp_bootFixedAttributes'),
+			'maintenanceFixedAttributes': choices('maintenanceFixedAttributes'),
+			'masterPackagesFixedAttributes': choices('masterPackagesFixedAttributes'),
+			'memberPackagesFixedAttributes': choices('memberPackagesFixedAttributes'),
+			'pwhistoryFixedAttributes': choices('pwhistoryFixedAttributes'),
+			'registryFixedAttributes': choices('registryFixedAttributes'),
+			'releaseFixedAttributes': choices('releaseFixedAttributes'),
+			'repositorySyncFixedAttributes': choices('repositorySyncFixedAttributes'),
+			'shareUserQuotaFixedAttributes': choices('shareUserQuotaFixedAttributes'),
+			'slavePackagesFixedAttributes': choices('slavePackagesFixedAttributes'),
+			'umcFixedAttributes': choices('umcFixedAttributes'),
+			'updateFixedAttributes': choices('updateFixedAttributes'),
+			'printerACLTypes': choices('printerACLTypes'),
+			'cscPolicy': choices('cscPolicy'),
+			'ldapFilter': lambda: '(objectClass=*)',
+			'UNIX_AccessRight': lambda: oct(random.randint(0, 0o777)).replace('o', ''),
+			'UNIX_AccessRight_extended': lambda: oct(random.randint(0, 0o2777)).replace('o', ''),
+			'timeperiod': lambda: ','.join(
+				'-'.join((uts.random_time((a, b)), uts.random_time((c, d))))
+				for a, b, c, d in random.choices(((0, 2, 4, 6), (8, 10, 10, 12), (24, 16, 18, 20), (20, 21, 22, 23)), k=random.randint(1, 4))
+			),
+			'listAttributes': uts.random_string,
+			'ldapDn': lambda: self.LDAP_BASE,  # only relevant for settings/syntax:base
+			'filesize': lambda: '%d%s%s' % (random.randint(0, 100), random.choice('gGmMkK'), random.choice('bB')),
+			# 'PortalCategorySelection': uts.random_string, kein bock... deprecated
+		}
+		module_property_mapping = {
+			'sambaRID': lambda: None,  # uts.random_int(1000, 9999),  # prevent The relative ID (SAMBA) is already in use: 5608
+			'uidNumber': lambda: None,  # prevent noLock / already used
+			'gidNumber': lambda: None,  # prevent noLock / already used
+			'mailForwardAddress': None,  # depends on mailPrimaryAddress
+			'preferredDeliveryMethod': lambda: random.choice(["any", "mhs", "physical", "telex", "teletex", "g3fax", "g4fax", "ia5", "videotex", "telephone"]),
+			'shell': lambda: random.choice(['/bin/false', '/bin/bash', '/bin/sh', '/usr/sbin/nologin']),
+			'shares/share': {
+				'sambaCustomSettings': lambda: random.choice(['"acl xattr update mtime" yes', '"access based share enum" yes', '"follow symlinks" "yes"']),
+			},
+			'dns/reverse_zone': {
+				'contact': syntax_classes_mapping['emailAddress'],  # Bug #53794
+			},
+			'dns/ptr_record': {
+				'ip': None,  # prevent, that a ip is set. instead address is set, which builds the ip from address.$superordinate
+			},
+			'settings/extended_attribute': {
+				'version': lambda: '2',  # other versions aren't detected as extended attribute!
+			},
+			'computers/windows': {
+				'ntCompatibility': lambda: '0',  # Bug #53819
+			},
+			'settings/mswmifilter': {
+				'description': None,  # Bug #53797
+				'displayName': None,  # Bug #53797
+			},
+			"settings/directory": {
+				"policies": default_container,
+				"dns": default_container,
+				"dhcp": default_container,
+				"users": default_container,
+				"groups": default_container,
+				"computers": default_container,
+				"domaincontroller": default_container,
+				"networks": default_container,
+				"shares": default_container,
+				"printers": default_container,
+				"mail": default_container,
+				"license": default_container,
+				"base": default_container,
+			},
+			'users/user': {
+				'userCertificate': lambda: base64.b64encode(subprocess.check_output(
+					('openssl', 'x509', '-inform', 'pem', '-in', '/etc/univention/ssl/%s/cert.pem' % (self.FQHN.rstrip('.'),), '-outform', 'der', '-out', '-')
+				)).decode('ASCII'),  # expensive!
+			},
+		}
+
+		def _func(func, prop):
+			if 'prop' in getargspec(func).args:
+				func = functools.partial(func, prop)
+			return func
+
+		for name, prop in module.property_descriptions.items():
+			if name in kwargs:
+				continue
+			if not prop.editable:  # or (is_modification and not prop.may_change)
+				continue
+			func = module_property_mapping.get(modulename, {}).get(name, module_property_mapping.get(name, syntax_classes_mapping.get(prop.syntax.name)))
+			if not func:
+				continue
+			func = _func(func, prop)
+
+			value = list(set(func() for i in range(random.randint(int(prop.required or name in ('ip', 'range')), 4)))) if prop.multivalue else func()
+			if value is None or isinstance(value, list) and all(v is None for v in value):
+				continue
+			kwargs.setdefault(name, value)
+
+		if modulename == 'shares/printer':
+			# when creating a shares/printergroup recursion is prevented: circular references aren't created
+			# therefore set some (invalid) values here
+			kwargs.setdefault('spoolHost', 'localhost')
+			kwargs.setdefault('model', 'cups-pdf/CUPS-PDF_noopt.ppd FAKE')
+
+		if modulename in ('dhcp/subnet', 'dhcp/sharedsubnet'):
+			import ipaddress
+			kwargs['subnetmask'] = str(min(29, int(kwargs['subnetmask'])))
+			iface = ipaddress.IPv4Interface(u'%(subnet)s/%(subnetmask)s' % kwargs)
+			kwargs['subnet'] = str(iface.network.network_address)
+		elif modulename in ('dhcp/pool',):
+			import ipaddress
+			iface = ipaddress.IPv4Interface(u'%(subnet)s/%(subnetmask)s' % superordinate_props)
+			if kwargs.get('dynamic_bootp_clients') != 'deny':
+				kwargs.pop('failover_peer')
+		if modulename in ('dhcp/subnet', 'dhcp/sharedsubnet', 'dhcp/pool'):
+			hosts = iface.network.hosts()
+			next(hosts)
+			ranges = []
+			for i in range(len(kwargs['range']) if isinstance(kwargs['range'], list) else 1):
+				first = last = None
+				try:
+					first = last = next(hosts)
+					for i in range(random.randrange(20)):
+						last = next(hosts)
+				except StopIteration:
+					pass
+				if first and first != last:
+					ranges.append('%s %s' % (first, last))
+				else:
+					break
+			kwargs['range'] = ranges
+
+		return self.create_object(modulename, **kwargs), kwargs
+
 	def modify_object(self, modulename, wait_for_replication=True, check_for_drs_replication=False, wait_for=False, **kwargs):
 		# type: (str, bool, bool, bool, **Any) -> str
 		"""
@@ -642,6 +1077,9 @@ class UCSTestUDM(object):
 		"""
 		Automatically removes LDAP objects via UDM CLI that have been created before.
 		"""
+		if not self._cleanup and not self._cleanupLocks:
+			return
+
 		failedObjects = {}
 		print('Performing UCSTestUDM cleanup...')
 		objects = []
